@@ -2,23 +2,25 @@ from __future__ import annotations
 
 import contextlib
 import importlib
+import importlib.util
 import itertools
 import json
 import operator
 import os
 import site
 import sys
+import typing
 from pathlib import Path
 from sysconfig import get_paths, get_python_version, get_scheme_names
 
-import pkg_resources
-
 import pipenv
+from pipenv import cmdparse
 from pipenv.patched.pip._internal.commands.install import InstallCommand
 from pipenv.patched.pip._internal.index.package_finder import PackageFinder
 from pipenv.patched.pip._internal.req.req_uninstall import UninstallPathSet
+from pipenv.patched.pip._vendor import pkg_resources
 from pipenv.patched.pip._vendor.packaging.utils import canonicalize_name
-from pipenv.utils.constants import is_type_checking
+from pipenv.utils.funktools import chunked, unnest
 from pipenv.utils.indexes import prepare_pip_source_args
 from pipenv.utils.processes import subprocess_run
 from pipenv.utils.shell import make_posix, normalize_path
@@ -32,16 +34,14 @@ except ImportError:
     from pipenv.patched.pip._vendor.distlib.util import cached_property
 
 
-if is_type_checking():
+if typing.TYPE_CHECKING:
     from types import ModuleType
     from typing import ContextManager, Dict, Generator, List, Optional, Set, Union
 
-    import tomlkit
-
     from pipenv.project import Project, TPipfile, TSource
+    from pipenv.vendor import tomlkit
 
 BASE_WORKING_SET = pkg_resources.WorkingSet(sys.path)
-# TODO: Unittests for this class
 
 
 class Environment:
@@ -313,19 +313,12 @@ class Environment:
             return sys.path
         elif any([sys.prefix == self.prefix, not self.is_venv]):
             return sys.path
-        cmd_args = [self.python, "-c", "import json, sys; print(json.dumps(sys.path))"]
-        path, _ = vistir.misc.run(
-            cmd_args,
-            return_object=False,
-            nospin=True,
-            block=True,
-            combine_stderr=False,
-            write_to_stdout=False,
-        )
+
         try:
-            path = json.loads(path.strip())
-        except json.JSONDecodeError:
+            path = pipenv.utils.shell.load_path(self.python)
+        except json.decoder.JSONDecodeError:
             path = sys.path
+
         return path
 
     def build_command(
@@ -724,8 +717,6 @@ class Environment:
         yield new_node
 
     def reverse_dependencies(self):
-        from vistir.misc import chunked, unnest
-
         rdeps = {}
         for req in self.get_package_requirements():
             for d in self.reverse_dependency(req):
@@ -817,7 +808,7 @@ class Environment:
 
         c = None
         with self.activated():
-            script = vistir.cmdparse.Script.parse(cmd)
+            script = cmdparse.Script.parse(cmd)
             c = vistir.misc.run(
                 script._parts,
                 return_object=True,
@@ -839,9 +830,9 @@ class Environment:
 
         c = None
         if isinstance(cmd, str):
-            script = vistir.cmdparse.Script.parse(f"{self.python} -c {cmd}")
+            script = cmdparse.Script.parse(f"{self.python} -c {cmd}")
         else:
-            script = vistir.cmdparse.Script.parse([self.python, "-c"] + list(cmd))
+            script = cmdparse.Script.parse([self.python, "-c"] + list(cmd))
         with self.activated():
             c = vistir.misc.run(
                 script._parts,
@@ -863,7 +854,7 @@ class Environment:
                 exec(code, dict(__file__=activate_this))
 
     @contextlib.contextmanager
-    def activated(self, include_extras=True, extra_dists=None):
+    def activated(self):
         """Helper context manager to activate the environment.
 
         This context manager will set the following variables for the duration
@@ -882,16 +873,8 @@ class Environment:
         to `os.environ["PATH"]` to ensure that calls to `~Environment.run()` use the
         environment's path preferentially.
         """
-
-        if not extra_dists:
-            extra_dists = []
         original_path = sys.path
         original_prefix = sys.prefix
-        parent_path = Path(__file__).absolute().parent
-        vendor_dir = parent_path.joinpath("vendor").as_posix()
-        patched_dir = parent_path.joinpath("patched").as_posix()
-        parent_path = parent_path.as_posix()
-        self.add_dist("pip")
         prefix = self.prefix.as_posix()
         with vistir.contextmanagers.temp_environ(), vistir.contextmanagers.temp_path():
             os.environ["PATH"] = os.pathsep.join(
@@ -914,21 +897,6 @@ class Environment:
                     os.environ.pop("PYTHONHOME", None)
             sys.path = self.sys_path
             sys.prefix = self.sys_prefix
-            site.addsitedir(self.base_paths["purelib"])
-            pip = self.safe_import("pip")  # noqa
-            pip_vendor = self.safe_import("pip._vendor")
-            pep517_dir = os.path.join(os.path.dirname(pip_vendor.__file__), "pep517")
-            site.addsitedir(pep517_dir)
-            os.environ["PYTHONPATH"] = os.pathsep.join(
-                [os.environ.get("PYTHONPATH", self.base_paths["PYTHONPATH"]), pep517_dir]
-            )
-            if include_extras:
-                site.addsitedir(parent_path)
-                sys.path.extend([parent_path, patched_dir, vendor_dir])
-                extra_dists = list(self.extra_dists) + extra_dists
-                for extra_dist in extra_dists:
-                    if extra_dist not in self.get_working_set():
-                        extra_dist.activate(self.sys_path)
             try:
                 yield
             finally:
